@@ -6,10 +6,12 @@
 #include <QTextStream>
 #include <QTimer>
 #include <QNetworkReply>
+#include <QNetworkCookie>
 #include <QNetworkAccessManager>
 #include <QNetworkDiskCache>
 #include <QNetworkProxy>
 #include <QByteArray>
+#include "maemocookiejar.h"
 
 
 
@@ -43,7 +45,8 @@ class HttpConnector : public QObject {
                 QNetworkAccessManager *http;
                 QNetworkDiskCache *cache;
                 QNetworkReply *reply;
-                QNetworkCookieJar *cookies;
+                MaemoCookieJar *cookies;
+                QList <QNetworkCookie> storedCoockies;
                 int timeout;
                 QTimer *timer;
                 bool busy;
