@@ -18,7 +18,8 @@ MaemoApplication::MaemoApplication (QString _name,
                   QString _comments,
                   QString _version,
                   QString _pre,
-                  QString _bpre
+                  QString _bpre,
+                  QString _pers
                   ) {
     this->name = _name;
     this->uid = _uid;
@@ -29,6 +30,7 @@ MaemoApplication::MaemoApplication (QString _name,
     this->version = _version;
     this->preview = _pre;
     this->bigPreview = _bpre;
+    this->personId =_pers;
 }
 
 MaemoApplication::MaemoApplication (QString _uid) {
@@ -41,6 +43,7 @@ MaemoApplication::MaemoApplication (QString _uid) {
     this->title = "";
     this->preview ="";
     this->bigPreview="";
+    this->personId = "";
 }
 
 void MaemoApplication::setBigPreview(QString _bpre) {
@@ -79,10 +82,18 @@ void MaemoApplication::setPreview (QString _pre) {
     this->preview = _pre;
 }
 
+void MaemoApplication::setPersonId (QString _per) {
+    personId = _per;
+}
+
 QString MaemoApplication::getBigPreview() {
     return this->bigPreview;
 }
 
+QString MaemoApplication::getPersonId() {
+    return personId;
+}
+
 QString MaemoApplication::getComments () {
     return this->comments;
 }
