@@ -11,6 +11,8 @@ class MaemoApplicationDetails : public MaemoApplication {
     public:
         MaemoApplicationDetails();
         ~MaemoApplicationDetails();
+
+        enum order {DESC,NORM};
         //set parameters
         void setDesc (QString);
         void setLicence (QString);
@@ -19,12 +21,14 @@ class MaemoApplicationDetails : public MaemoApplication {
         void setInstallFileContent (QString);
         void setRevisor (QString);
         void addScreenshot (QString);
-        void addUserComment (MaemoComment*);
+        void addUserComment (MaemoComment*,int order=NORM);
         void setUnparsedComments (QByteArray);
+        void setBugUrl (QString);
 
 
         //get parameters
         QString getDescription ();
+        QString getBugUrl();
         QString getLicence ();
         QString getStatus ();
         QString getInstallFile ();
@@ -47,6 +51,7 @@ class MaemoApplicationDetails : public MaemoApplication {
         QString installFile;
         QString installFileContent;
         QString revisor;
+        QString bugUrl;
         QList <QString> *screenshots;
         QList <MaemoComment*> *userComments;
         QByteArray unparsedComments;
