@@ -9,21 +9,25 @@ class QueueElement : public QObject {
 
     public:
         QueueElement ();
-        QueueElement (QString _url,QString _id="",QString _info="");
+        QueueElement (QString _url,QString _id="",QString _info="",int type = IMAGE);
 
         QString getID ();
         QString getURL ();
         QString getInfo();
+        int getType ();
 
         void setID (QString);
         void setURL (QString);
         void setInfo (QString);
+        void setType (int);
 
+        enum request_type {IMAGE,LIST,DETAILS};
 
     private:
         QString url;
         QString id;
         QString info;
+        int type;
 
     };
 #endif // QUEUEELEMENT_H
